@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import sys
 from typing import Any, AsyncContextManager
 
@@ -13,19 +11,26 @@ class EmptyCls(object):
         raise ModuleNotInstalledException()
 
 
+try:
+    import orjson as json
+except ImportError:
+    import json
+
 try:
     import aiofiles
 except ImportError:
+
     class aiofiles_compat:
         def open(self, *args: Any, **kwargs: Any) -> AsyncContextManager[Any]:
             raise ModuleNotInstalledException(
                 "Module aiofiles not installed and you can't use it's "
                 "functionality till you install this module."
             )
+
     aiofiles = aiofiles_compat()  # type: ignore
 
 try:
-    import orjson as json
+    import orjson as json  # noqa
 except (ImportError, ModuleNotFoundError):
     import json  # type: ignore
 
@@ -37,7 +42,6 @@ except (ModuleNotFoundError, ImportError):
     InputFile = EmptyCls
 
 if sys.version_info >= (3, 8):
-    from typing import Literal as Literal
-    from typing import Final as Final
+    from typing import Final, Literal, Protocol  # noqa
 else:
-    from typing_extensions import Literal, Final
+    from typing_extensions import Final, Literal, Protocol  # noqa
